@@ -36,13 +36,14 @@ class BandoriApi(BandoriLoader):
         Get events by ids, as Event objects.
         If the list is empty, will get all events.
         '''
+        if not id:
+            events = self._full_event_loader(url=self.URL_PARTY+'events/')
+        else:
+            events = self._api_get(id=id, url=self.URL_PARTY+'events/')
+            for i, event in enumerate(events):
+                event['id'] = id[i]
 
-                # How to get by id? bandori.party doesn't provide event_id
-                # (but it's still possible to search by id).
-
-        d = self._api_get(id=id, url=self.URL_PARTY+'events/')
-
-        return [Event(event) for event in d]
+        return [Event(event) for event in events]
 
     def get_current_event(self):
         '''
@@ -51,7 +52,7 @@ class BandoriApi(BandoriLoader):
         event = self._retrieve_response(self.URL_GA+'event/')
         id = event["eventId"] + 3 # offset of 3 to get the bandori.party events
 
-        return self.get_events(id=[id])
+        return self.get_events(id=[id])[0]
 
     
     def get_costumes(self, id : list = []):
@@ -145,3 +146,23 @@ class BandoriApi(BandoriLoader):
             d = d["data"]
 
         return [Gacha(data, region=self.region) for data in d]
+    
+    def get_all(self):
+        '''
+        Get all possible objects from the apis
+        '''
+        d = {'cards': [], 'members': [], 'events': [], 'costumes': [], 'items': [],
+                'areaitems': [], 'assets' : {}, 'bands' : [], 'songs' : [], 'gachas' : []}
+        
+        d['cards'].extend(self.get_cards())
+        d['members'].extend(self.get_members())
+        d['events'].extend(self.get_events())
+        d['costumes'].extend(self.get_costumes())
+        d['items'].extend(self.get_items())
+        d['areaitems'].extend(self.get_areaitems())
+        d['assets'].update(self.get_assets())
+        d['bands'].extend(self.get_bands())
+        d['songs'].extend(self.get_songs())
+        d['gachas'].extend(self.get_gachas())
+
+        return d
\ No newline at end of file
